@@ -1,10 +1,11 @@
 import whois
 import logging
+import requests
 
 def whois_plugin(data):
     try:
         hostDict = whois.whois(data)
-
+        hostDict = dict(hostDict)
         # change domain list from list to string
         if isinstance(hostDict.get('domain_name'), list):
             hostDict['domain_name'] = hostDict['domain_name'][0].lower()
@@ -13,13 +14,12 @@ def whois_plugin(data):
         hostDict.update({ 'verified': False })
 
         # search for domain in 500DB
-        with open ('CyvoreOS/Resources/top500urls.txt', 'r') as urls:
-            for url in urls:
-                if hostDict['domain_name'] in url:
-                    hostDict['verified'] = True
-                    break
-            urls.close()
-        
+        urlManifest = requests.get('https://raw.githubusercontent.com/Cyvore/IconDB/master/Resources/top500urls.txt').text.split('\n')
+        for url in urlManifest:
+            if hostDict['domain_name'] in url:
+                hostDict['verified'] = True
+                break
+
         return hostDict
     except Exception as e:
         logging.warning(e)
