@@ -110,12 +110,13 @@ class Case:
     Case is an object to investigate multiple leads from the same source. 
     checkArray will hold every lead and will only repersent one value - url/file/crypto wallet.
     """  
-    def __init__(self, raw):
+    def __init__(self, raw, empty=False):
         logging.info("Initializing Case")
         self.caseID = self.getCaseID()
         self.checkArray = []
         self.raw = raw
-        self.createChecks()
+        if not empty:
+            self.createChecks()
         self.timestemp = datetime.now().strftime("%m%d%Y%H%M%S")
         logging.debug(f"Created case {self.caseID} with {self.size()} checks")
         
